pywws.LogData — pywws 13.06_r1023 documentation

### Navigation

- index
- modules |
- suivant |
- précédent |
- pywws 13.06_r1023 documentation »
- Programmes et des modules Python »

# pywws.LogData

Enregistre l’historique de la station météo dans un fichier

    usage: python -m pywws.LogData [options] data_dir
    options are:
     -h   | --help     display this help
     -c   | --clear    clear weather station's memory full indicator
     -s n | --sync n   set quality of synchronisation to weather station (0 or 1)
     -v   | --verbose  increase number of informative messages
    data_dir is the root directory of the weather data

Ce programme / module reçoit les données de la mémoire de la station météo et les stockent dans un fichier. Chaque fois qu’il est lancé, il récupère toutes les données qui sont plus récentes que les dernières données enregistrées, de sorte qu’il ne doit être exécuté que toutes les heures. Comme la station météorologique stocke généralement deux semaines de lectures (en fonction de l’intervalle d’enregistrement), LogData.py pourrait être exécuté très rarement si vous n’avez pas besoin de données fréquemment mise à jour.

Il n’y a aucune information sur la date ou l’heure dans les données brutes de la station météo, alors LogData.py crée un horodatage pour chaque lecture. Il utilise l’horloge de l’ordinateur, plutôt que l’horloge de la station météo qui peut ne pas être lue correctement par l’ordinateur. L’horloge d’un Pc en réseau devrait être réglée avec précision par ntp.

La synchronisation avec la station météo est obtenue par l’attente d’un changement dans les données en cours. Il y a deux niveaux de synchronisation, fixés par le fichier de configuration ou une option de ligne de commande. Le niveau 0 est plus rapide, mais n’est exacte qu’à environ douze secondes. Le niveau 1 attend jusqu’à ce que la station météo enregistre un nouvel enregistrement, et obtient un horodatage précis sur quelque secondes. Notez que cela peut prendre un certain temps, si l’intervalle d’enregistrement est supérieur aux cinq minutes recommandées.

Fonctions

`Catchup`(ws, logger, raw_data, last_date, ...) |
`CheckFixedBlock`(ws, params, status, logger) |
`LogData`(params, status, raw_data[, sync, clear]) |
`main`([argv]) |

`pywws.LogData.` `Catchup`(ws, logger, raw_data, last_date, last_ptr)

`pywws.LogData.` `CheckFixedBlock`(ws, params, status, logger)

`pywws.LogData.` `LogData`(params, status, raw_data, sync=None, clear=False)

`pywws.LogData.` `main`(argv=None)

### Navigation

- index
- modules |
- suivant |
- précédent |
- pywws 13.06_r1023 documentation »
- Programmes et des modules Python »